
# The different «shadowColor» options to show
options = [
	"red"
	"green"
	"#05F"
	"black"
	"rgba(171,21,0,1)"
]

# Animation duration
Framer.Defaults.Animation.time = 1


# Adjust the Text Layer’s height automatically
theTextLayer.autoHeight = yes


# Functions for the slider

# round number to a set amount
round = (number, nearest) ->
	Math.round(number / nearest) * nearest


# - add dots for increments to slider
# - enforce increments
# - change title on value change

applyIncrements = (slider,options) ->
	
	latestOption = null
	
	sizeOfDots = slider.height + 2
	stepAmount = options.length
	
	stepDistanceDots = ( slider.width - sizeOfDots ) / ( stepAmount - 1 )
	stepDistanceKnob = slider.width / ( stepAmount - 1 )
	
	for i in [0...stepAmount]
		dot = new Layer 
			size: sizeOfDots
			borderRadius: sizeOfDots / 1.5
			superLayer: slider
			backgroundColor: artboard.backgroundColor
			x: (stepDistanceDots * i)
		
		dot.placeBehind slider.knob
		dot.y = Align.center
	
	slider.min = 0
	slider.max = stepAmount-1
	
	slider.onValueChange ->
		# only animate when changing to a new value
		# (and not when simply releasing the knob)
		# + don’t animate when a button was tapped
		if options[Utils.round @value] isnt latestOption and animatingToOption is 0
			# make the text a bit smaller
			theTextLayer.scale = 0.97
			# apple new value
			theTextLayer.shadowColor = options[Utils.round @value]
			# scale back up
			theTextLayer.animate
				scale: 1
				options:
					time: .3
					curve: "Spring"
			
			latestOption = options[Utils.round @value]
		
		if Utils.round @value is 0
			title.template =
				v: ""
				d: "«default»"
		else
			title.template =
				v: "\"#{options[Utils.round @value]}\""
				d: ""
	
	slider.knob.draggable.updatePosition = (point) ->
		point.x = round(point.x, stepDistanceKnob) - (slider.knob.width / 2)
		return point

# Setup title

title.template =
	v: ""
	d: "«default»"

if Screen.height > Screen.width		# portrait orientation ?
	if Screen.height <= 667			# on an iPhone 6 (or smaller) ?
		title.fontSize = 15

# Slider
slider = new SliderComponent
	height: 5
	width: Screen.width - 50
	knobSize: 25
	backgroundColor: "rgba(255,255,255,0.5)"
	x: 25
	maxY: Screen.height - buttonA.height - 55
slider.fill.backgroundColor = "#fff"

# add the default option
options.unshift "rgba(123, 123, 123, 0.5)"

# add interval points to the slider
applyIncrements slider, options

# Setup buttons

for button in [buttonA, buttonB, buttonC]
	# Resize horizontally
	button.width = ( Screen.width - 100 ) / 3
	# Change color on tap and release
	button.onTouchStart ->
		@backgroundColor = "#fff"
		@children[0].color = artboard.backgroundColor
	button.onTouchEnd ->
		@backgroundColor = artboard.backgroundColor
		@children[0].color = "#fff"

# Setup animations

animatingToOption = 0

# animate to the first option
buttonA.children[0].text = options[1]
animateToColor1 = new Animation theTextLayer,
	shadowColor: options[1]
buttonA.onTap ->
	animateToColor1.start()
	animatingToOption = 1
	latestOption = options[1]

# animate to the second option
buttonB.children[0].text = options[2]
animateToColor2 = new Animation theTextLayer,
	shadowColor: options[2]
buttonB.onTap ->
	animateToColor2.start()
	animatingToOption = 2
	latestOption = options[2]

# animate to the third option
buttonC.children[0].text = options[3]
animateToColor3 = new Animation theTextLayer,
	shadowColor: options[3]
buttonC.onTap ->
	animateToColor3.start()
	animatingToOption = 3
	latestOption = options[3]

# reposition slider knob after animation
animateToColor1.onAnimationEnd ->
	slider.value = animatingToOption
	animatingToOption = 0	# clear the fact that a button was tapped

animateToColor2.onAnimationEnd ->
	slider.value = animatingToOption
	animatingToOption = 0

animateToColor3.onAnimationEnd ->
	slider.value = animatingToOption
	animatingToOption = 0
